@@ -2,6 +2,7 @@ from .features.adnormal import *
 from .features.amplitude import *
 from .features.beyondnstd import *
 from .features.bins import *
+from .features.color_of_median import *
 from .features.cusum import *
 from .features.eta import *
 from .features.etae import *
@@ -23,7 +24,10 @@ from .features.median import *
 from .features.otsusplit import *
 from .features.pdiffmperc import *
 from .features.percampl import *
+from .features.ptp_var import *
+from .features.rainbow import *
 from .features.redchi2 import *
+from .features.roms import *
 from .features.skew import *
 from .features.stdev import *
 from .features.stetsonk import *
