@@ -1,17 +1,22 @@
 from dataclasses import dataclass
 
 import numpy as np
-from scipy import ndimage
 
-from ._base_meta import BaseMetaFeature
+from ..dataclass_field import dataclass_field
+from ._base_meta import BaseMetaSingleBandFeature
 
 
 @dataclass()
-class Bins(BaseMetaFeature):
-    window: float = 1.0
-    offset: float = 0.0
+class Bins(BaseMetaSingleBandFeature):
+    window: float = dataclass_field(default=1.0, kw_only=True)
+    offset: float = dataclass_field(default=0.0, kw_only=True)
+
+    def transform(self, t, m, sigma=None, *, sorted=None, fill_value=None):
+        try:
+            from scipy import ndimage
+        except ImportError:
+            raise ImportError("scipy is required for Bins feature, please install it")
 
-    def transform(self, t, m, sigma=None, sorted=None, fill_value=None):
         assert self.window > 0, "Window should be a positive number."
         n = np.ceil((t[-1] - t[0]) / self.window) + 1
         j = np.arange(0, n)
