@@ -1,15 +1,15 @@
 import numpy as np
 
-from ._base import BaseFeature
+from ._base import BaseSingleBandFeature
 
 
-class PercentAmplitude(BaseFeature):
-    def _eval(self, t, m, sigma=None):
+class PercentAmplitude(BaseSingleBandFeature):
+    def _eval_single_band(self, t, m, sigma=None):
         median = np.median(m)
         return np.max((np.max(m) - median, median - np.min(m)))
 
     @property
-    def size(self):
+    def size_single_band(self):
         return 1
 
 
