@@ -11,7 +11,7 @@ import_exception!(pickle, PicklingError);
 import_exception!(pickle, UnpicklingError);
 
 #[allow(clippy::enum_variant_names)]
-#[derive(Clone, Error, Debug)]
+#[derive(Error, Debug)]
 #[error("{0}")]
 pub(crate) enum Exception {
     // builtins
@@ -23,6 +23,8 @@ pub(crate) enum Exception {
     // pickle
     PicklingError(String),
     UnpicklingError(String),
+    // some exception from pyo3 which we need to handle
+    PyO3(#[from] PyErr),
 }
 
 impl From<Exception> for PyErr {
@@ -37,6 +39,8 @@ impl From<Exception> for PyErr {
             // pickle
             Exception::PicklingError(err) => PicklingError::new_err(err),
             Exception::UnpicklingError(err) => UnpicklingError::new_err(err),
+            // pyo3
+            Exception::PyO3(err) => err,
         }
     }
 }
