@@ -3,12 +3,12 @@ from functools import lru_cache, wraps
 from itertools import count
 from pathlib import Path
 from typing import Generator, Iterator, List, Optional, Union
-from joblib import Parallel, delayed
 
 import feets
 import numpy as np
 import pandas as pd
 import pytest
+from joblib import Parallel, delayed
 from numpy.testing import assert_allclose
 from scipy import stats
 from scipy.optimize import curve_fit
@@ -104,6 +104,8 @@ class _Test:
     name = None
     # Argument tuple for the feature constructor
     args = ()
+    # And keyword arguments
+    kwargs = {}
 
     py_feature = None
 
@@ -120,11 +122,16 @@ class _Test:
     phot_types = Data.phot_type_choices
 
     def setup_method(self):
-        self.rust = getattr(lc_ext, self.name)(*self.args)
+        self.rust = getattr(lc_ext, self.name)(*self.args, **self.kwargs)
+
         try:
-            self.py_feature = getattr(lc_py, self.name)(*self.args)
+            self.py_feature_cls = getattr(lc_py, self.name)
         except AttributeError:
             pass
+        else:
+            if len(self.args) > 0:
+                raise ValueError("Py features must be called with keyword arguments only")
+            self.py_feature = self.py_feature_cls(**self.kwargs)
 
         if self.feets_feature is not None:
             self.feets_extractor = feets.FeatureSpace(only=[self.feets_feature], data=["time", "magnitude", "error"])
@@ -287,69 +294,92 @@ class TestAndersonDarlingNormal(_Test):
         return stats.anderson(m).statistic * (1.0 + 4.0 / m.size - 25.0 / m.size**2)
 
 
+class _TestBazinFit:
+    name = "BazinFit"
+    kwargs = {"mcmc_niter": 1 << 10, "ceres_niter": 20, "lmsder_niter": 20}
+    rtol = 1e-3  # 10x of the precision used in the feature implementation
+
+    add_to_all_features = False  # in All* random data is used
+
+    phot_types = frozenset(["flux"])
+
+    @staticmethod
+    def _model(t, a, b, t0, rise, fall):
+        dt = t - t0
+        return b + a * np.exp(-dt / fall) / (1.0 + np.exp(-dt / rise))
+
+    def _params(self):
+        a = 100
+        c = 100
+        t0 = 0.5 * (self.t_min + self.t_max)
+        rise = 0.1 * (self.t_max - self.t_min)
+        fall = 0.2 * (self.t_max - self.t_min)
+        return a, c, t0, rise, fall
+
+    # Random data yields to random results because target function has a lot of local minima
+    # BTW, this test shouldn't use fixed random seed because the curve has good enough S/N to be fitted for any give
+    # noise sample
+    def random_data(self):
+        rng = np.random.default_rng(0)
+        t = np.linspace(self.t_min, self.t_max, self.n_obs)
+        model = self._model(t, *self._params())
+        sigma = np.sqrt(model)
+        m = model + sigma * rng.normal(size=self.n_obs)
+        return Data("Bazin+noise", "flux", t, m, sigma)
+
+    # Keep random data only
+    def data_gen(self) -> Generator[Data, None, None]:
+        yield self.random_data()
+        # All these fail because curve_fit is not good enough or because of the multiple local minima
+        # yield from get_first_n_snia_data(n=10, convert_to_flux=True)
+
+    def naive(self, t, m, sigma):
+        params, _cov = curve_fit(
+            self._model,
+            xdata=t,
+            ydata=m,
+            sigma=sigma,
+            xtol=self.rtol,
+            # We give really good parameters' estimation!
+            # p0=self._params(),
+            # The same parameter estimations we use in Rust
+            p0=(0.5 * np.ptp(m), np.min(m), t[np.argmax(m)], 0.5 * np.ptp(t), 0.5 * np.ptp(t)),
+        )
+        reduced_chi2 = np.sum(np.square((self._model(t, *params) - m) / sigma)) / (t.size - params.size)
+        return_value = tuple(params) + (reduced_chi2,)
+        return return_value
+
+
+@pytest.mark.skip("Runs too long")
+class TestBazinFitMcmc(_TestBazinFit, _Test):
+    args = ("mcmc",)
+
+
+if lc_ext._built_with_ceres:
+
+    class TestBazinFitCeres(_TestBazinFit, _Test):
+        args = ("ceres",)
+
+    @pytest.mark.skip("Runs too long")
+    class TestBazinFitMcmcCeres(_TestBazinFit, _Test):
+        args = ("mcmc-ceres",)
+
+
 if lc_ext._built_with_gsl:
 
-    class TestBazinFit(_Test):
-        name = "BazinFit"
-        args = ("lmsder", None, 20)
-        rtol = 1e-4  # Precision used in the feature implementation
+    class TestBazinFitLmsder(_TestBazinFit, _Test):
+        args = ("lmsder",)
 
-        add_to_all_features = False  # in All* random data is used
-
-        phot_types = frozenset(["flux"])
-
-        @staticmethod
-        def _model(t, a, b, t0, rise, fall):
-            dt = t - t0
-            return b + a * np.exp(-dt / fall) / (1.0 + np.exp(-dt / rise))
-
-        def _params(self):
-            a = 100
-            c = 100
-            t0 = 0.5 * (self.t_min + self.t_max)
-            rise = 0.1 * (self.t_max - self.t_min)
-            fall = 0.2 * (self.t_max - self.t_min)
-            return a, c, t0, rise, fall
-
-        # Random data yields to random results because target function has a lot of local minima
-        # BTW, this test shouldn't use fixed random seed because the curve has good enough S/N to be fitted for any give
-        # noise sample
-        def random_data(self):
-            rng = np.random.default_rng(0)
-            t = np.linspace(self.t_min, self.t_max, self.n_obs)
-            model = self._model(t, *self._params())
-            sigma = np.sqrt(model)
-            m = model + sigma * rng.normal(size=self.n_obs)
-            return Data("Bazin+noise", "flux", t, m, sigma)
-
-        # Keep random data only
-        def data_gen(self) -> Generator[Data, None, None]:
-            yield self.random_data()
-            # All these fail =(
-            # yield from get_first_n_snia_data(n=10, convert_to_flux=True)
-
-        def naive(self, t, m, sigma):
-            params, _cov = curve_fit(
-                self._model,
-                xdata=t,
-                ydata=m,
-                sigma=sigma,
-                xtol=self.rtol,
-                # We give really good parameters estimation!
-                # p0=self._params(),
-                # The same parameter estimations we use in Rust
-                p0=(0.5 * np.ptp(m), np.min(m), t[np.argmax(m)], 0.5 * np.ptp(t), 0.5 * np.ptp(t)),
-            )
-            reduced_chi2 = np.sum(np.square((self._model(t, *params) - m) / sigma)) / (t.size - params.size)
-            return_value = tuple(params) + (reduced_chi2,)
-            return return_value
+    @pytest.mark.skip("Runs too long")
+    class TestBazinFitMcmcLmsder(_TestBazinFit, _Test):
+        args = ("mcmc-lmsder",)
 
 
 class TestBeyond1Std(_Test):
     nstd = 1.0
 
     name = "BeyondNStd"
-    args = (nstd,)
+    kwargs = dict(nstd=nstd)
 
     feets_feature = "Beyond1Std"
     feets_skip_test = "feets uses biased statistics"
@@ -399,7 +429,7 @@ class TestInterPercentileRange(_Test):
     quantile = 0.25
 
     name = "InterPercentileRange"
-    args = (quantile,)
+    kwargs = dict(quantile=quantile)
 
     feets_feature = "Q31"
     feets_skip_test = "feets uses different quantile type"
@@ -448,14 +478,14 @@ class TestLinearTrend(_Test):
         return np.array([slope, np.sqrt(slope_sigma2), sigma_noise])
 
 
-def generate_test_magnitude_percentile_ratio(quantile_numerator, quantile_denumerator, feets_feature):
+def generate_test_magnitude_percentile_ratio(quantile_numerator, quantile_denominator, feets_feature):
     return type(
         f"TestMagnitudePercentageRatio{int(quantile_numerator * 100):d}",
         (_Test,),
         dict(
-            args=(quantile_numerator, quantile_denumerator),
+            kwargs=dict(quantile_numerator=quantile_numerator, quantile_denominator=quantile_denominator),
             quantile_numerator=quantile_numerator,
-            quantile_denumerator=quantile_denumerator,
+            quantile_denominator=quantile_denominator,
             name="MagnitudePercentageRatio",
             feets_feature=feets_feature,
             feets_skip_test="feets uses different quantile type",
@@ -515,7 +545,7 @@ class TestMedianBufferRangePercentage(_Test):
     quantile = 0.2
 
     name = "MedianBufferRangePercentage"
-    args = (quantile,)
+    kwargs = dict(quantile=quantile)
 
     feets_feature = "MedianBRP"
 
@@ -535,7 +565,7 @@ class TestPercentDifferenceMagnitudePercentile(_Test):
     quantile = 0.05
 
     name = "PercentDifferenceMagnitudePercentile"
-    args = (quantile,)
+    kwargs = dict(quantile=quantile)
 
     feets_feature = "PercentDifferenceFluxPercentile"
     feets_skip_test = "feets uses different quantile type"
@@ -549,6 +579,10 @@ class TestReducedChi2(_Test):
         return np.sum(np.square(m - np.average(m, weights=w)) * w) / (m.size - 1)
 
 
+class TestRoms(_Test):
+    name = "Roms"
+
+
 class TestSkew(_Test):
     name = "Skew"
 
@@ -598,10 +632,10 @@ class TestAllPy(_Test):
                 continue
 
             try:
-                py_features.append(getattr(lc_py, cls.name)(*cls.args))
+                py_features.append(getattr(lc_py, cls.name)(**cls.kwargs))
             except AttributeError:
                 continue
-            features.append(getattr(lc_ext, cls.name)(*cls.args))
+            features.append(getattr(lc_ext, cls.name)(**cls.kwargs))
         self.rust = lc_ext.Extractor(*features)
         self.py_feature = lc_py.Extractor(*py_features)
 
@@ -636,10 +670,10 @@ class TestBenchmarkParallel(_Test):
                 continue
 
             try:
-                py_features.append(getattr(lc_py, cls.name)(*cls.args))
+                py_features.append(getattr(lc_py, cls.name)(**cls.kwargs))
             except AttributeError:
                 continue
-            features.append(getattr(lc_ext, cls.name)(*cls.args))
+            features.append(getattr(lc_ext, cls.name)(**cls.kwargs))
         self.rust = lc_ext.Extractor(*features)
         self.py_feature = lc_py.Extractor(*py_features)
 
@@ -714,7 +748,7 @@ class TestAllNaive(_Test):
                 continue
             if not cls.add_to_all_features:
                 continue
-            features.append(getattr(lc_ext, cls.name)(*cls.args))
+            features.append(getattr(lc_ext, cls.name)(*cls.args, **cls.kwargs))
             self.naive_features.append(cls().naive)
         self.rust = lc_ext.Extractor(*features)
 
@@ -738,7 +772,7 @@ class TestAllFeets(_Test):
                 continue
             if not cls.add_to_all_features:
                 continue
-            features.append(getattr(lc_ext, cls.name)(*cls.args))
+            features.append(getattr(lc_ext, cls.name)(*(cls.args + tuple(cls.kwargs.values()))))
             feets_features.append(cls.feets_feature)
         self.rust = lc_ext.Extractor(*features)
         self.feets_extractor = feets.FeatureSpace(only=feets_features, data=["time", "magnitude", "error"])
